The CredentialManager Instance
==============================

.. autoclass:: credmgr.CredentialManager
    :inherited-members:

.. toctree::
    :maxdepth: 2
    :caption: Helper Classes
    :glob:

    credmgr/*
